# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.models.image import Image

class TestImage(unittest.TestCase):
    """Image unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Image:
        """Test Image
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Image`
        """
        model = Image()
        if include_optional:
            return Image(
                frames = '15',
                height = '200',
                mp4 = 'https://media1.giphy.com/media/cZ7rmKfFYOvYI/giphy.mp4',
                mp4_size = '25123',
                size = '32381',
                url = 'https://media1.giphy.com/media/cZ7rmKfFYOvYI/200.gif',
                webp = 'https://media1.giphy.com/media/cZ7rmKfFYOvYI/giphy.webp',
                webp_size = '12321',
                width = '320'
            )
        else:
            return Image(
        )
        """

    def testImage(self):
        """Test Image"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
