# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.models.gif_images import GifImages

class TestGifImages(unittest.TestCase):
    """GifImages unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GifImages:
        """Test GifImages
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GifImages`
        """
        model = GifImages()
        if include_optional:
            return GifImages(
                downsized = None,
                downsized_large = None,
                downsized_medium = None,
                downsized_small = None,
                downsized_still = None,
                fixed_height = None,
                fixed_height_downsampled = None,
                fixed_height_small = None,
                fixed_height_small_still = None,
                fixed_height_still = None,
                fixed_width = None,
                fixed_width_downsampled = None,
                fixed_width_small = None,
                fixed_width_small_still = None,
                fixed_width_still = None,
                looping = None,
                original = None,
                original_still = None,
                preview = None,
                preview_gif = None
            )
        else:
            return GifImages(
        )
        """

    def testGifImages(self):
        """Test GifImages"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
