# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.api.gifs_api import GifsApi


class TestGifsApi(unittest.TestCase):
    """GifsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GifsApi()

    def tearDown(self) -> None:
        pass

    def test_get_gif_by_id(self) -> None:
        """Test case for get_gif_by_id

        Get GIF by Id
        """
        pass

    def test_get_gifs_by_id(self) -> None:
        """Test case for get_gifs_by_id

        Get GIFs by ID
        """
        pass

    def test_random_gif(self) -> None:
        """Test case for random_gif

        Random GIF
        """
        pass

    def test_search_gifs(self) -> None:
        """Test case for search_gifs

        Search GIFs
        """
        pass

    def test_translate_gif(self) -> None:
        """Test case for translate_gif

        Translate phrase to GIF
        """
        pass

    def test_trending_gifs(self) -> None:
        """Test case for trending_gifs

        Trending GIFs
        """
        pass


if __name__ == '__main__':
    unittest.main()
