# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from tester_sdk.models.get_gifs_by_id200_response import GetGifsById200Response
from tester_sdk.models.random_gif200_response import RandomGif200Response

from tester_sdk.api_client import ApiClient, RequestSerialized
from tester_sdk.api_response import ApiResponse
from tester_sdk.rest import RESTResponseType


class StickersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def random_sticker(
        self,
        tag: Annotated[Optional[StrictStr], Field(description="Filters results by specified tag.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RandomGif200Response:
        """Random Sticker

        Returns a random GIF, limited by tag. Excluding the tag parameter will return a random GIF from the GIPHY catalog. 

        :param tag: Filters results by specified tag.
        :type tag: str
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._random_sticker_serialize(
            tag=tag,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def random_sticker_with_http_info(
        self,
        tag: Annotated[Optional[StrictStr], Field(description="Filters results by specified tag.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[RandomGif200Response]:
        """Random Sticker

        Returns a random GIF, limited by tag. Excluding the tag parameter will return a random GIF from the GIPHY catalog. 

        :param tag: Filters results by specified tag.
        :type tag: str
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._random_sticker_serialize(
            tag=tag,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def random_sticker_without_preload_content(
        self,
        tag: Annotated[Optional[StrictStr], Field(description="Filters results by specified tag.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Random Sticker

        Returns a random GIF, limited by tag. Excluding the tag parameter will return a random GIF from the GIPHY catalog. 

        :param tag: Filters results by specified tag.
        :type tag: str
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._random_sticker_serialize(
            tag=tag,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _random_sticker_serialize(
        self,
        tag,
        rating,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if tag is not None:
            
            _query_params.append(('tag', tag))
            
        if rating is not None:
            
            _query_params.append(('rating', rating))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/random',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def search_stickers(
        self,
        q: Annotated[StrictStr, Field(description="Search query term or prhase.")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        lang: Annotated[Optional[StrictStr], Field(description="Specify default language for regional content; use a 2-letter ISO 639-1 language code.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> GetGifsById200Response:
        """Search Stickers

        Replicates the functionality and requirements of the classic GIPHY search, but returns animated stickers rather than GIFs. 

        :param q: Search query term or prhase. (required)
        :type q: str
        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :param lang: Specify default language for regional content; use a 2-letter ISO 639-1 language code.
        :type lang: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_stickers_serialize(
            q=q,
            limit=limit,
            offset=offset,
            rating=rating,
            lang=lang,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_stickers_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="Search query term or prhase.")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        lang: Annotated[Optional[StrictStr], Field(description="Specify default language for regional content; use a 2-letter ISO 639-1 language code.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[GetGifsById200Response]:
        """Search Stickers

        Replicates the functionality and requirements of the classic GIPHY search, but returns animated stickers rather than GIFs. 

        :param q: Search query term or prhase. (required)
        :type q: str
        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :param lang: Specify default language for regional content; use a 2-letter ISO 639-1 language code.
        :type lang: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_stickers_serialize(
            q=q,
            limit=limit,
            offset=offset,
            rating=rating,
            lang=lang,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_stickers_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="Search query term or prhase.")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        lang: Annotated[Optional[StrictStr], Field(description="Specify default language for regional content; use a 2-letter ISO 639-1 language code.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Search Stickers

        Replicates the functionality and requirements of the classic GIPHY search, but returns animated stickers rather than GIFs. 

        :param q: Search query term or prhase. (required)
        :type q: str
        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :param lang: Specify default language for regional content; use a 2-letter ISO 639-1 language code.
        :type lang: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_stickers_serialize(
            q=q,
            limit=limit,
            offset=offset,
            rating=rating,
            lang=lang,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _search_stickers_serialize(
        self,
        q,
        limit,
        offset,
        rating,
        lang,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if rating is not None:
            
            _query_params.append(('rating', rating))
            
        if lang is not None:
            
            _query_params.append(('lang', lang))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def translate_sticker(
        self,
        s: Annotated[StrictStr, Field(description="Search term.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RandomGif200Response:
        """Translate phrase to Sticker

        The translate API draws on search, but uses the GIPHY `special sauce` to handle translating from one vocabulary to another. In this case, words and phrases to GIFs. 

        :param s: Search term. (required)
        :type s: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_sticker_serialize(
            s=s,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def translate_sticker_with_http_info(
        self,
        s: Annotated[StrictStr, Field(description="Search term.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[RandomGif200Response]:
        """Translate phrase to Sticker

        The translate API draws on search, but uses the GIPHY `special sauce` to handle translating from one vocabulary to another. In this case, words and phrases to GIFs. 

        :param s: Search term. (required)
        :type s: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_sticker_serialize(
            s=s,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def translate_sticker_without_preload_content(
        self,
        s: Annotated[StrictStr, Field(description="Search term.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Translate phrase to Sticker

        The translate API draws on search, but uses the GIPHY `special sauce` to handle translating from one vocabulary to another. In this case, words and phrases to GIFs. 

        :param s: Search term. (required)
        :type s: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_sticker_serialize(
            s=s,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _translate_sticker_serialize(
        self,
        s,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if s is not None:
            
            _query_params.append(('s', s))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/translate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def trending_stickers(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> GetGifsById200Response:
        """Trending Stickers

        Fetch Stickers currently trending online. Hand curated by the GIPHY editorial team. Returns 25 results by default. 

        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._trending_stickers_serialize(
            limit=limit,
            offset=offset,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def trending_stickers_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[GetGifsById200Response]:
        """Trending Stickers

        Fetch Stickers currently trending online. Hand curated by the GIPHY editorial team. Returns 25 results by default. 

        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._trending_stickers_serialize(
            limit=limit,
            offset=offset,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def trending_stickers_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Trending Stickers

        Fetch Stickers currently trending online. Hand curated by the GIPHY editorial team. Returns 25 results by default. 

        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._trending_stickers_serialize(
            limit=limit,
            offset=offset,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _trending_stickers_serialize(
        self,
        limit,
        offset,
        rating,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if rating is not None:
            
            _query_params.append(('rating', rating))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/trending',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )


