# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.api.stickers_api import StickersApi


class TestStickersApi(unittest.TestCase):
    """StickersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StickersApi()

    def tearDown(self) -> None:
        pass

    def test_random_sticker(self) -> None:
        """Test case for random_sticker

        Random Sticker
        """
        pass

    def test_search_stickers(self) -> None:
        """Test case for search_stickers

        Search Stickers
        """
        pass

    def test_translate_sticker(self) -> None:
        """Test case for translate_sticker

        Translate phrase to Sticker
        """
        pass

    def test_trending_stickers(self) -> None:
        """Test case for trending_stickers

        Trending Stickers
        """
        pass


if __name__ == '__main__':
    unittest.main()
